@@ -1,6 +1,7 @@
 import datetime
 import logging
-import subprocess
+import os
+import subprocess  # nosec B404
 from pathlib import Path
 from shutil import which
 
@@ -49,13 +50,28 @@ class Git:
         if not self.git_bin:
             raise GitBinNotFoundError()
 
+        self.env = dict(os.environ)
+        # no translated git command output ;)
+        self.env['LANG'] = 'en_US.UTF-8'
+        self.env['LANGUAGE'] = 'en_US'
+
     def git_verbose_check_call(self, *popenargs, **kwargs):
         popenargs = [self.git_bin, *popenargs]
-        return verbose_check_call(*popenargs, cwd=self.cwd, **kwargs)
+        return verbose_check_call(
+            *popenargs,
+            cwd=self.cwd,
+            env=self.env,
+            **kwargs,
+        )
 
     def git_verbose_check_output(self, *popenargs, **kwargs):
         popenargs = [self.git_bin, *popenargs]
-        return verbose_check_output(*popenargs, cwd=self.cwd, **kwargs)
+        return verbose_check_output(
+            *popenargs,
+            cwd=self.cwd,
+            env=self.env,
+            **kwargs,
+        )
 
     def git_verbose_output(
         self, *popenargs, exit_on_error=False, ignore_process_error=True, **kwargs
@@ -186,6 +202,22 @@ class Git:
         lines = output.splitlines()
         return lines
 
+    def tag(self, git_tag: str, message: str):
+        self.git_verbose_check_call('tag', '-a', git_tag, '-m', message)
+
+    def push(self, tags=False):
+        if tags:
+            args = ['--tags']
+        else:
+            args = []
+
+        self.git_verbose_check_call('push', *args)
+
+    def tag_list(self, verbose=True, exit_on_error=True) -> list[str]:
+        output = self.git_verbose_check_output('tag', verbose=verbose, exit_on_error=exit_on_error)
+        lines = output.splitlines()
+        return lines
+
     def ls_files(self, verbose=True) -> list[Path]:
         output = self.git_verbose_check_output('ls-files', verbose=verbose, exit_on_error=True)
         file_paths = []
@@ -209,3 +241,15 @@ class Git:
         assert output.startswith(
             test_str
         ), f'Reset error: {output!r} does not start with {test_str!r}'
+
+    def status(self, verbose=True) -> list:
+        """
+        Returns the changed files, if any.
+        """
+        output = self.git_verbose_check_output('status', '--porcelain', verbose=verbose, exit_on_error=True)
+        result = []
+        for line in output.splitlines():
+            line = line.strip()
+            status, filepath = line.split(' ', 1)
+            result.append((status, filepath))
+        return result
